from dataharvest.spider.common_spider import CommonSpider
from dataharvest.spider.toutiao_spider import ToutiaoSpider
from dataharvest.spider.spider import AutoSpider, BaseSpider

__all__ = ["AutoSpider", "CommonSpider", "BaseSpider", "ToutiaoSpider"]
